@@ -78,7 +78,9 @@ autodoc_member_order = 'groupwise'
 
 autosectionlabel_prefix_document = True
 
-extlinks = {'pypi': ('https://pypi.org/project/%s/', '')}
+autosummary_mock_imports = ['ctypes', 'linkcheck.__main__']
+
+extlinks = {'pypi': ('https://pypi.org/project/%s/', '%s')}
 
 graphviz_output_format = 'svg'
 
@@ -93,4 +95,4 @@ sitemap_url_scheme = "{link}"
 
 import linkcheck.logger
 linkcheck.logger.failures.FailuresLogger.LoggerArgs = {
-    'filename': '~/.linkchecker/failures'}
+    'filename': '$XDG_DATA_HOME/linkchecker/failures'}
