@@ -1,5 +1,4 @@
-# -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2008 Bastian Kleineidam
+# Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,40 +10,39 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """
 A dummy logger.
 """
-
-import linkcheck.logger
+from . import _Logger
 
 
-class NoneLogger (linkcheck.logger.Logger):
+class NoneLogger(_Logger):
     """
     Dummy logger printing nothing.
     """
 
-    def comment (self, s, **args):
+    LoggerName = 'none'
+
+    def comment(self, s, **args):
         """
         Do nothing.
         """
         pass
 
-    def start_output (self):
+    def start_output(self):
         """
         Do nothing.
         """
         pass
 
-    def log_filter_url (self, url_data, do_filter):
-        """
-        Do nothing.
-        """
+    def log_url(self, url_data):
+        """Do nothing."""
         pass
 
-    def end_output (self):
+    def end_output(self, **kwargs):
         """
         Do nothing.
         """
