@@ -64,7 +64,7 @@ def has_word():
         key = winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, "Word.Application")
         winreg.CloseKey(key)
         return True
-    except (EnvironmentError, ImportError):
+    except (OSError, ImportError):
         pass
     return False
 
@@ -115,7 +115,7 @@ class WordParser(_ParserPlugin):
     """Word parsing plugin."""
 
     def __init__(self, config):
-        """Check for pdfminer."""
+        """Check for Word."""
         init_win32com()
         if not has_word():
             log.warn(LOG_PLUGIN, "Microsoft Word not found for WordParser plugin")
@@ -138,7 +138,7 @@ class WordParser(_ParserPlugin):
                     raise Error("could not open word file %r" % filename)
                 try:
                     for link in doc.Hyperlinks:
-                        line = get_line_number(link.Range)
+                        line = get_line_number(doc, link.Range)
                         name = link.TextToDisplay
                         url_data.add_url(link.Address, name=name, line=line)
                 finally:
